/*
 * JCuda - Java bindings for NVIDIA CUDA driver and runtime API
 * http://www.jcuda.org
 *
 * Copyright 2009-2012 Marco Hutter - http://www.jcuda.org
 */

package org.jcuda.samples.matrix.cg;

import jcuda.driver.CUdeviceptr;
import jcuda.jcusparse.cusparseMatDescr;

/**
 * Interface for a float matrix that is stored in CSR format on the device
 */
public interface FloatMatrixDeviceCSR extends Matrix, DeviceData
{
    /**
     * Returns the number of non-zero entries 
     * 
     * @return The number of non-zero entries 
     */
    int getNumNonZeros();
    
    /**
     * Returns the non-zero values  
     * 
     * @return The non-zero values 
     */
    CUdeviceptr getValues();

    /**
     * Returns the row pointers 
     * 
     * @return The row pointers 
     */
    CUdeviceptr getRowPointers();

    /**
     * Return the column indices 
     * 
     * @return The column indices 
     */
    CUdeviceptr getColumnIndices();
    
    /**
     * Returns the CUSPARSE matrix descriptor 
     * 
     * @return The descriptor 
     */
    cusparseMatDescr getDescriptor();
    
}
